# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/moblyze/crew/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/moblyze/crew/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Moblyze\\Crew\\": "packages/moblyze/crew/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Moblyze\Crew\Providers\CrewServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Crew'  => Moblyze\Crew\Facades\Crew::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Moblyze\\CrewTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Moblyze\Crew\Providers\CrewServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Moblyze\Crew\Providers\CrewServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Moblyze\Crew\Providers\CrewServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/crew/{modulename}

**User**

    http://path-to-route-folder/user/crew/{modulename}

**Public**

    http://path-to-route-folder/crews


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/crew/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/crew/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/crew/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/crew/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/crew/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/crew/{modulename}/{slug}
    METHOD: GET