<?php

namespace Moblyze\Crew\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Crew\Models\Crew;

class CrewPolicy
{

    /**
     * Determine if the given user can view the crew.
     *
     * @param UserPolicy $user
     * @param Crew $crew
     *
     * @return bool
     */
    public function view(UserPolicy $user, Crew $crew)
    {
        if ($user->canDo('crew.crew.view') && $user->isAdmin()) {
            return true;
        }

        return $crew->user_id == user_id() && $crew->user_type == user_type();
    }

    /**
     * Determine if the given user can create a crew.
     *
     * @param UserPolicy $user
     * @param Crew $crew
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('crew.crew.create');
    }

    /**
     * Determine if the given user can update the given crew.
     *
     * @param UserPolicy $user
     * @param Crew $crew
     *
     * @return bool
     */
    public function update(UserPolicy $user, Crew $crew)
    {
        if ($user->canDo('crew.crew.edit') && $user->isAdmin()) {
            return true;
        }

        return $crew->user_id == user_id() && $crew->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given crew.
     *
     * @param UserPolicy $user
     * @param Crew $crew
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Crew $crew)
    {
        return $crew->user_id == user_id() && $crew->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given crew.
     *
     * @param UserPolicy $user
     * @param Crew $crew
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Crew $crew)
    {
        if ($user->canDo('crew.crew.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given crew.
     *
     * @param UserPolicy $user
     * @param Crew $crew
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Crew $crew)
    {
        if ($user->canDo('crew.crew.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
