<?php

namespace Moblyze\Crew\Providers;

use Illuminate\Support\ServiceProvider;

class CrewServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'crew');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'crew');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCrew();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCrew()
    {
        $this->app->bind('crew', function($app) {
            return new Crew($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Crew', 'Lavalite\Crew\Facades\Crew');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('moblyze.crew', function ($app) {
            return $this->app->make('Moblyze\Crew\Crew');
        });

        // Bind Crew to repository
        $this->app->bind(
            'Moblyze\Crew\Interfaces\CrewRepositoryInterface',
            \Moblyze\Crew\Repositories\Eloquent\CrewRepository::class
        );
        // Bind Plan to repository
        $this->app->bind(
            'Moblyze\Crew\Interfaces\PlanRepositoryInterface',
            \Moblyze\Crew\Repositories\Eloquent\PlanRepository::class
        );

        $this->app->register(\Moblyze\Crew\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Moblyze\Crew\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and crew's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'moblyze.crew'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCrew::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['moblyze.crew'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('moblyze/crew.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/crew')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/crew')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
